# typtrain - practice typing
単純なtuiタイピング練習ツール

## インストール

```
pip install typtrain
```

Windowsは以下も必要:

```
pip install windows-curses
```

## 使い方
コマンドラインで以下を実行:

```
typtrain
```

制限時間60秒の中で、できるだけ多くの単語を打ち込んでください。  
連続して成功すればスコアが加速度的に増えます。

また、単語のリストを自分で用意する場合は、[dic.csv](typtrain/assets/dic.csv)を参考にcsv形式で用意し、コマンドの引数にファイル名を指定してください。

## お願い
結果をSNS等にシェアするときは、「#typtrain」をつけてください。作者が喜びます。

## ライセンス
このプログラムはMIT-Licenceのもとにあります。  
[LICENCE](LICENCE)も参照してください。

## 作者
Laddge
